@@ -95,15 +95,19 @@ dépasse 64 caractères"
         temoin = True
         vraiefin = False
         motdepasse = '"'
-        while temoin == True:
+        while temoin:
             debut = ligne.find(' "')
             if debut != -1:
                 intermediaire = ligne[debut+2:]
-                while vraiefin == False:
-                    prochain = intermediaire.find('"')
-                    motdepasse = motdepasse + intermediaire[:prochain+1]
-                    if motdepasse[-2] == '\\':
-                        intermediaire = intermediaire[prochain+1:]
+                #while vraiefin == False:
+                while not vraiefin: 
+                    if '"' in intermediaire:
+                        prochain = intermediaire.find('"')
+                        motdepasse = motdepasse + intermediaire[:prochain+1]
+                        if motdepasse[-2] == '\\':
+                            intermediaire = intermediaire[prochain+1:]
+                        else:
+                            vraiefin = True
                     else:
                         vraiefin = True
                 chaine = motdepasse
@@ -122,12 +126,12 @@ dépasse 64 caractères"
         """On traite la fin d'une liste d'ordres"""
         if (self.ordres[num] == linesep and self.script[-1] != self.entetel2)\
 or (num + 1 == len(self.ordres) and self.script[-1] != self.entetel2):
-            if self.commande == False:
+            if not self.commande:
                 self.script.append('interact +++ return\n')
             else:
                 self.script.append('expect eof\n')
-            resultat = abspath(join(self.destination + self.machinefinale
-                                                 + self.extfichier))
+            resultat = abspath(join(self.destination,
+                 ''.join([self.machinefinale, self.extfichier])))
             try:
                 open(resultat, 'w').writelines(self.script)
                 chmod(resultat, stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR )
@@ -144,7 +148,7 @@ or (num + 1 == len(self.ordres) and self.script[-1] != self.entetel2):
         port = ''
         ligne = self.ordres[num]
         if ligne != linesep:
-            if self.commande == True:
+            if self.commande:
                 self.traite_commande(ligne)
             else:
                 machine = ligne.split()[0]
@@ -152,18 +156,20 @@ or (num + 1 == len(self.ordres) and self.script[-1] != self.entetel2):
                 if ':' in self.machinefinale:
                     self.machinefinale, port = self.machinefinale.split(':')
                     machine = ligne.split()[0].split(':')[0]
-                if self.premiereligne == True:
+                if self.premiereligne:
                     if port == '':
                         self.script.append('spawn ssh %s\n' % machine)
                         self.premiereligne = False
                     else:
-                        self.script.append('spawn ssh -p %s %s\n' % (port, machine))
+                        self.script.append('spawn ssh -p %s %s\n' %
+                                                 (port, machine))
                         self.premiereligne = False
                 else:
                     if port == '':
                         self.script.append('send "ssh %s\\r"\n' % machine)
                     else:
-                        self.script.append('send "ssh -p %s %s\\r"\n' % (port, machine))
+                        self.script.append('send "ssh -p %s %s\\r"\n' %
+                                                     (port, machine))
                 if ligne.split()[-1] == '-c':
                     self.avec_commande(ligne)
                     self.commande = True
@@ -221,7 +227,7 @@ or (num + 1 == len(self.ordres) and self.script[-1] != self.entetel2):
 
     def prepare_prompt(self):
         """Prépare le prompt en fonction de l'identité de l'utilisateur""" 
-        if self.utilisateurroot == True :
+        if self.utilisateurroot:
             self.script.append('expect "#"\n')
         else:
             self.script.append('expect "$"\n')
